@@ -34,6 +34,7 @@ const FavoritesPopover = imports.favoritesPopover;
 const Geoclue = imports.geoclue;
 const LayersPopover = imports.layersPopover;
 const LocationServiceNotification = imports.locationServiceNotification;
+const MapSource = imports.mapSource;
 const MapView = imports.mapView;
 const PlaceEntry = imports.placeEntry;
 const PlaceStore = imports.placeStore;
@@ -66,6 +67,8 @@ const MainWindow = new Lang.Class({
         this.mapView = new MapView.MapView();
         overlay.add(this.mapView);
 
+        overlay.add_overlay(new MapSource.AttributionLogo());
+
         this.mapView.gotoUserLocation(false);
 
         this._sidebar = this._createSidebar();
